pub struct FontInfoStore<S: AsRef<str>, F: FnMut(&str) -> S> { /* private fields */ }Expand description
A font info store takes care of parsing the pdftex.map file and the .enc and .pfb files
to obtain information about fonts.
Implementations
Sourceimpl<S: AsRef<str>, F: FnMut(&str) -> S> FontInfoStore<S, F>
impl<S: AsRef<str>, F: FnMut(&str) -> S> FontInfoStore<S, F>
Sourcepub fn new(get: F) -> Self
pub fn new(get: F) -> Self
Create a new font info store. The function get is used to obtain the
full file paths of files based on their names; the canonical
implementation would be to call kpsewhich.
Sourcepub fn display_encoding<S2: AsRef<str>>(
&mut self,
name: S2,
) -> Option<impl Display + '_>
pub fn display_encoding<S2: AsRef<str>>( &mut self, name: S2, ) -> Option<impl Display + '_>
Displays the FontInfo and GlyphList of a font as a Markdown table, as it would
appear in patches.md.